@@ -1,7 +1,10 @@
 import functools
 from typing import Any
 
-from starlette._utils import is_async_callable
+import pytest
+
+from starlette._utils import get_route_path, is_async_callable
+from starlette.types import Scope
 
 
 def test_async_func() -> None:
@@ -78,3 +81,15 @@ def test_async_nested_partial() -> None:
     partial = functools.partial(async_func, b=2)
     nested_partial = functools.partial(partial, a=1)
     assert is_async_callable(nested_partial)
+
+
+@pytest.mark.parametrize(
+    "scope, expected_result",
+    [
+        ({"path": "/foo-123/bar", "root_path": "/foo"}, "/foo-123/bar"),
+        ({"path": "/foo/bar", "root_path": "/foo"}, "/bar"),
+        ({"path": "/foo", "root_path": "/foo"}, ""),
+    ],
+)
+def test_get_route_path(scope: Scope, expected_result: str) -> None:
+    assert get_route_path(scope) == expected_result
