@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import datetime as dt
-import os
 import time
 from http.cookies import SimpleCookie
 from pathlib import Path
@@ -119,9 +118,7 @@ def test_streaming_response(test_client_factory: TestClientFactory) -> None:
 
         cleanup_task = BackgroundTask(numbers_for_cleanup, start=6, stop=9)
         generator = numbers(1, 5)
-        response = StreamingResponse(
-            generator, media_type="text/plain", background=cleanup_task
-        )
+        response = StreamingResponse(generator, media_type="text/plain", background=cleanup_task)
         await response(scope, receive, send)
 
     assert filled_by_bg_task == ""
@@ -215,11 +212,10 @@ def test_response_phrase(test_client_factory: TestClientFactory) -> None:
     assert response.reason_phrase == ""
 
 
-def test_file_response(tmpdir: Path, test_client_factory: TestClientFactory) -> None:
-    path = os.path.join(tmpdir, "xyz")
+def test_file_response(tmp_path: Path, test_client_factory: TestClientFactory) -> None:
+    path = tmp_path / "xyz"
     content = b"<file content>" * 1000
-    with open(path, "wb") as file:
-        file.write(content)
+    path.write_bytes(content)
 
     filled_by_bg_task = ""
 
@@ -238,9 +234,7 @@ def test_file_response(tmpdir: Path, test_client_factory: TestClientFactory) ->
     cleanup_task = BackgroundTask(numbers_for_cleanup, start=6, stop=9)
 
     async def app(scope: Scope, receive: Receive, send: Send) -> None:
-        response = FileResponse(
-            path=path, filename="example.png", background=cleanup_task
-        )
+        response = FileResponse(path=path, filename="example.png", background=cleanup_task)
         await response(scope, receive, send)
 
     assert filled_by_bg_task == ""
@@ -258,11 +252,10 @@ def test_file_response(tmpdir: Path, test_client_factory: TestClientFactory) ->
 
 
 @pytest.mark.anyio
-async def test_file_response_on_head_method(tmpdir: Path) -> None:
-    path = os.path.join(tmpdir, "xyz")
+async def test_file_response_on_head_method(tmp_path: Path) -> None:
+    path = tmp_path / "xyz"
     content = b"<file content>" * 1000
-    with open(path, "wb") as file:
-        file.write(content)
+    path.write_bytes(content)
 
     app = FileResponse(path=path, filename="example.png")
 
@@ -287,20 +280,28 @@ async def test_file_response_on_head_method(tmpdir: Path) -> None:
     await app({"type": "http", "method": "head"}, receive, send)
 
 
-def test_file_response_with_directory_raises_error(
-    tmpdir: Path, test_client_factory: TestClientFactory
-) -> None:
-    app = FileResponse(path=tmpdir, filename="example.png")
+def test_file_response_set_media_type(tmp_path: Path, test_client_factory: TestClientFactory) -> None:
+    path = tmp_path / "xyz"
+    path.write_bytes(b"<file content>")
+
+    # By default, FileResponse will determine the `content-type` based on
+    # the filename or path, unless a specific `media_type` is provided.
+    app = FileResponse(path=path, filename="example.png", media_type="image/jpeg")
+    client: TestClient = test_client_factory(app)
+    response = client.get("/")
+    assert response.headers["content-type"] == "image/jpeg"
+
+
+def test_file_response_with_directory_raises_error(tmp_path: Path, test_client_factory: TestClientFactory) -> None:
+    app = FileResponse(path=tmp_path, filename="example.png")
     client = test_client_factory(app)
     with pytest.raises(RuntimeError) as exc_info:
         client.get("/")
     assert "is not a file" in str(exc_info.value)
 
 
-def test_file_response_with_missing_file_raises_error(
-    tmpdir: Path, test_client_factory: TestClientFactory
-) -> None:
-    path = os.path.join(tmpdir, "404.txt")
+def test_file_response_with_missing_file_raises_error(tmp_path: Path, test_client_factory: TestClientFactory) -> None:
+    path = tmp_path / "404.txt"
     app = FileResponse(path=path, filename="404.txt")
     client = test_client_factory(app)
     with pytest.raises(RuntimeError) as exc_info:
@@ -308,14 +309,11 @@ def test_file_response_with_missing_file_raises_error(
     assert "does not exist" in str(exc_info.value)
 
 
-def test_file_response_with_chinese_filename(
-    tmpdir: Path, test_client_factory: TestClientFactory
-) -> None:
+def test_file_response_with_chinese_filename(tmp_path: Path, test_client_factory: TestClientFactory) -> None:
     content = b"file content"
     filename = "你好.txt"  # probably "Hello.txt" in Chinese
-    path = os.path.join(tmpdir, filename)
-    with open(path, "wb") as f:
-        f.write(content)
+    path = tmp_path / filename
+    path.write_bytes(content)
     app = FileResponse(path=path, filename=filename)
     client = test_client_factory(app)
     response = client.get("/")
@@ -325,14 +323,11 @@ def test_file_response_with_chinese_filename(
     assert response.headers["content-disposition"] == expected_disposition
 
 
-def test_file_response_with_inline_disposition(
-    tmpdir: Path, test_client_factory: TestClientFactory
-) -> None:
+def test_file_response_with_inline_disposition(tmp_path: Path, test_client_factory: TestClientFactory) -> None:
     content = b"file content"
     filename = "hello.txt"
-    path = os.path.join(tmpdir, filename)
-    with open(path, "wb") as f:
-        f.write(content)
+    path = tmp_path / filename
+    path.write_bytes(content)
     app = FileResponse(path=path, filename=filename, content_disposition_type="inline")
     client = test_client_factory(app)
     response = client.get("/")
@@ -342,16 +337,12 @@ def test_file_response_with_inline_disposition(
     assert response.headers["content-disposition"] == expected_disposition
 
 
-def test_file_response_with_method_warns(
-    tmpdir: Path, test_client_factory: TestClientFactory
-) -> None:
+def test_file_response_with_method_warns(tmp_path: Path) -> None:
     with pytest.warns(DeprecationWarning):
-        FileResponse(path=tmpdir, filename="example.png", method="GET")
+        FileResponse(path=tmp_path, filename="example.png", method="GET")
 
 
-def test_set_cookie(
-    test_client_factory: TestClientFactory, monkeypatch: pytest.MonkeyPatch
-) -> None:
+def test_set_cookie(test_client_factory: TestClientFactory, monkeypatch: pytest.MonkeyPatch) -> None:
     # Mock time used as a reference for `Expires` by stdlib `SimpleCookie`.
     mocked_now = dt.datetime(2037, 1, 22, 12, 0, 0, tzinfo=dt.timezone.utc)
     monkeypatch.setattr(time, "time", lambda: mocked_now.timestamp())
@@ -375,18 +366,27 @@ def test_set_cookie(
     response = client.get("/")
     assert response.text == "Hello, world!"
     assert (
-        response.headers["set-cookie"]
-        == "mycookie=myvalue; Domain=localhost; expires=Thu, 22 Jan 2037 12:00:10 GMT; "
+        response.headers["set-cookie"] == "mycookie=myvalue; Domain=localhost; expires=Thu, 22 Jan 2037 12:00:10 GMT; "
         "HttpOnly; Max-Age=10; Path=/; SameSite=none; Secure"
     )
 
 
+def test_set_cookie_path_none(test_client_factory: TestClientFactory) -> None:
+    async def app(scope: Scope, receive: Receive, send: Send) -> None:
+        response = Response("Hello, world!", media_type="text/plain")
+        response.set_cookie("mycookie", "myvalue", path=None)
+        await response(scope, receive, send)
+
+    client = test_client_factory(app)
+    response = client.get("/")
+    assert response.text == "Hello, world!"
+    assert response.headers["set-cookie"] == "mycookie=myvalue; SameSite=lax"
+
+
 @pytest.mark.parametrize(
     "expires",
     [
-        pytest.param(
-            dt.datetime(2037, 1, 22, 12, 0, 10, tzinfo=dt.timezone.utc), id="datetime"
-        ),
+        pytest.param(dt.datetime(2037, 1, 22, 12, 0, 10, tzinfo=dt.timezone.utc), id="datetime"),
         pytest.param("Thu, 22 Jan 2037 12:00:10 GMT", id="str"),
         pytest.param(10, id="int"),
     ],
@@ -476,13 +476,10 @@ def test_response_do_not_add_redundant_charset(
     assert response.headers["content-type"] == "text/plain; charset=utf-8"
 
 
-def test_file_response_known_size(
-    tmpdir: Path, test_client_factory: TestClientFactory
-) -> None:
-    path = os.path.join(tmpdir, "xyz")
+def test_file_response_known_size(tmp_path: Path, test_client_factory: TestClientFactory) -> None:
+    path = tmp_path / "xyz"
     content = b"<file content>" * 1000
-    with open(path, "wb") as file:
-        file.write(content)
+    path.write_bytes(content)
 
     app = FileResponse(path=path, filename="example.png")
     client: TestClient = test_client_factory(app)
@@ -500,9 +497,7 @@ def test_streaming_response_unknown_size(
 
 
 def test_streaming_response_known_size(test_client_factory: TestClientFactory) -> None:
-    app = StreamingResponse(
-        content=iter(["hello", "world"]), headers={"content-length": "10"}
-    )
+    app = StreamingResponse(content=iter(["hello", "world"]), headers={"content-length": "10"})
     client: TestClient = test_client_factory(app)
     response = client.get("/")
     assert response.headers["content-length"] == "10"
